@@ -22,11 +22,10 @@
 import ast
 import os
 import re
-import warnings
 from typing import Dict, List, Optional, Union
 
 from databind.core import datamodel, field
-from nr.stream import chain, concat
+from nr.stream import chain, concat  # type: ignore
 
 from shut.utils.ast import load_module_members
 from shut.utils.fs import get_file_in_directory
@@ -34,7 +33,7 @@ from .author import Author
 from .abstract import AbstractProjectModel
 from .linter import LinterConfiguration
 from .publish import PublishConfiguration
-from .requirements import BaseRequirement, Requirement, RequirementsList
+from .requirements import Requirement, RequirementsList
 from .test import TestDriver
 from .version import Version
 
@@ -94,6 +93,8 @@ class PackageModel(AbstractProjectModel):
   requirements: RequirementsList = field(default_factory=RequirementsList)
   test_requirements: RequirementsList = field(altname='test-requirements', default_factory=RequirementsList)
   extra_requirements: Dict[str, RequirementsList] = field(altname='extra-requirements', default_factory=dict)
+  dev_requirements: RequirementsList = field(altname='dev-requirements', default_factory=RequirementsList)
+  render_requirements_txt: bool = field(altname='render-requirements-txt', default=False)
   source_directory: str = field(altname='source-directory', default='src')
   exclude: List[str] = field(default_factory=lambda: ['test', 'tests', 'docs'])
   entrypoints: Dict[str, List[str]] = field(default_factory=dict)
